Welcome to SynDisco’s documentation! — SynDisco 2.0.4 documentation

# Welcome to SynDisco’s documentation!

Welcome to the official documentation of SynDisco! This project provides a lightweight framework for creating, managing, annotating, and analyzing synthetic discussions between Large Language Model (LLM) user-agents in online forums.

# Introduction

- Overview
- Features
- Installation
- Guides
  - How to Create a Synthetic Discussion
  - How to Annotate your Synthetic Discussions
  - How to Use the Experiment API to Manage Large-Scale Studies
- syndisco package
  - Submodules
  - syndisco.actors module
  - syndisco.experiments module
  - syndisco.jobs module
  - syndisco.logging_util module
  - syndisco.model module
  - syndisco.postprocessing module
  - syndisco.turn_manager module
  - Module contents

# Indices and tables

- Index

- Module Index

- Search Page